References
----------

.. [Hastie09]
   Hastie *et al.* (2009),
   *The Elements of Statistical Learning*,
   Springer https://web.stanford.edu/~hastie/ElemStatLearn/.

.. [Huber15]
   Huber *et al.* (2015),
   *Orchestrating high-throughput genomic analysis with Bioconductor*,
   Nature Methods https://doi.org/10.1038/nmeth.3252.

.. [Murphy12]
   Murphy (2012,
   *Machine Learning: A Probabilistic Perspective*,
   MIT Press https://mitpress.mit.edu/9780262018029/machine-learning/.
